yt.visualization.base\_plot\_types module
=========================================

.. automodule:: yt.visualization.base_plot_types
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
